@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use v5.10;    # needed for state variable
 
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 our $AUTHORITY = 'cpan:NIGELM'; # AUTHORITY
 
 use Moose;
@@ -182,9 +182,15 @@ method _request ($method, $url, $content?, $headers?) {
 
     # Throw if this went wrong
     if ( $response->is_error ) {
-        my $message = "$method request failed";
-        try { $message .= ' - ' . $response->decoded_content->{Error}{'-message'}; }
-        catch { $message .= ' - Unknown'; }
+        my $message = "$method request failed [$uri] - ";
+        try {
+            my $decoded_response = $self->_decode_xml_response($response);
+            $message .=
+                ( exists( $decoded_response->{Error}{'-message'} ) )
+                ? $decoded_response->{Error}{'-message'}
+                : 'Unknown after decode';
+        }
+        catch { $message .= 'Unknown'; }
         VMware::vCloudDirector::Error->throw(
             {   message  => $message,
                 uri      => $uri,
@@ -444,7 +450,7 @@ VMware::vCloudDirector::API - Module to do stuff!
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head2 Attributes
 
